@@ -43,6 +43,7 @@
 #undef KDE_DOCDIR
 
 #undef HAVE_ZVT_TERM_RESET
+#undef HAVE_ZVT_DEL_IS_DEL
 
 #undef HAVE_HOSTS_ACCESS
 
@@ -53,3 +54,7 @@
 
 #undef HAVE__ICETRANSNOLISTEN
 #undef DO_LIBICE_CHECK
+
+#undef HAVE_LIBXINERAMA
+
+#undef HAVE_GNOME_PRINT
