@@ -1037,7 +1037,8 @@ task_notifier (gpointer func_data, GwmhTask *gwmh_task,
 	TasklistTask *task;
 	gboolean redraw = FALSE;
 	gboolean relayout = FALSE;
-
+	Pixmap newhinticon;
+	
 	switch (ntype)
 	{
 	case GWMH_NOTIFY_INFO_CHANGED:
@@ -1075,10 +1076,11 @@ task_notifier (gpointer func_data, GwmhTask *gwmh_task,
 
 
 		if (imask & GWMH_TASK_INFO_WM_HINTS) {
-			if (tasklist_icon_get_pixmap (task) !=
-			    task->wmhints_icon) {
+		        newhinticon = tasklist_icon_get_pixmap (task);
+			if ( newhinticon != task->wmhints_icon) {
 				tasklist_icon_destroy (task);
 				tasklist_icon_set (task);
+				task->wmhints_icon = newhinticon;
 				redraw = TRUE;
 			}
 		}
