@@ -33,6 +33,9 @@ extern int applet_count;
 static char *default_app_pixmap = NULL;
 
 extern GlobalConfig global_config;
+extern gboolean commie_mode;
+
+extern char *merge_merge_dir;
 
 extern GSList *panels;
 
@@ -79,8 +82,8 @@ launch (Launcher *launcher, int argc, char *argv[])
 
 		if (goad_id != NULL) {
 			load_extern_applet (goad_id, NULL,
-					    panels->data,
-					    0, FALSE, FALSE);
+					    NULL, -1,
+					    FALSE, FALSE);
 		} else {
 			g_warning (_("Can't get goad_id from desktop entry!"));
 		}
@@ -321,13 +324,32 @@ create_launcher (const char *parameters, GnomeDesktopEntry *dentry)
 			else
 				extension = ".desktop";
 
-			apps_par = g_strconcat ("apps/", parameters,
+			apps_par = g_strconcat ("gnome/apps/", parameters,
 						extension, NULL);
 			entry = gnome_datadir_file (apps_par);
 			g_free (apps_par);
 
-			if (entry == NULL)
+			if (entry == NULL) {
+				/* perhaps just datadir? */
+				entry = gnome_datadir_file (parameters);
+			}
+
+			if (entry == NULL && merge_merge_dir != NULL) {
+				/* the merge dir? */
+				entry = g_strconcat (merge_merge_dir, "/",
+						     parameters,
+						     extension, NULL);
+				if ( ! panel_file_exists (entry)) {
+					g_free (entry);
+					entry = NULL;
+				}
+			}
+
+			/* eek, not found */
+			if (entry == NULL) {
 				return NULL;
+			}
+
 			dentry = gnome_desktop_entry_load_unconditional (entry);
 			g_free (entry);
 		}
@@ -472,7 +494,9 @@ properties_apply (Launcher *launcher)
 		g_free (docpath);
 
 		title = g_strdup_printf (_("Help on %s"),
-					 launcher->dentry->name);
+					 launcher->dentry->name != NULL ?
+					 launcher->dentry->name :
+					 _("Application"));
 
 		applet_add_callback (launcher->info, "help_on_app",
 				     GNOME_STOCK_PIXMAP_HELP,
@@ -502,7 +526,7 @@ window_clicked (GtkWidget *w, int button, gpointer data)
 	Launcher *launcher = data;
 
 	if (button == HELP_BUTTON) {
-		panel_show_help ("launcher.html");
+		panel_show_help ("launchers.html");
 	} else if (button == REVERT_BUTTON) { /* revert */
 		gnome_dentry_edit_set_dentry (GNOME_DENTRY_EDIT (launcher->dedit),
 					      launcher->revert_dentry);
@@ -649,9 +673,10 @@ load_launcher_applet_full (const char *params, GnomeDesktopEntry *dentry,
 			      launcher->dentry->comment,
 			      NULL);
 
-	applet_add_callback (applets_last->data,"properties",
-			     GNOME_STOCK_MENU_PROP,
-			     _("Properties..."));
+	if ( ! commie_mode)
+		applet_add_callback (applets_last->data,"properties",
+				     GNOME_STOCK_MENU_PROP,
+				     _("Properties..."));
 	applet_add_callback (applets_last->data, "help",
 			     GNOME_STOCK_PIXMAP_HELP,
 			     _("Help"));
@@ -663,7 +688,9 @@ load_launcher_applet_full (const char *params, GnomeDesktopEntry *dentry,
 		g_free (docpath);
 
 		title = g_strdup_printf (_("Help on %s"),
-					 launcher->dentry->name);
+					 launcher->dentry->name != NULL ?
+					 launcher->dentry->name :
+					 _("Application"));
 
 		applet_add_callback (applets_last->data, "help_on_app",
 				     GNOME_STOCK_PIXMAP_HELP,
@@ -688,13 +715,13 @@ really_add_launcher(GtkWidget *dialog, int button, gpointer data)
 
 		dentry = gnome_dentry_get_dentry(dedit);
 
-		if(!dentry->name || !(*(dentry->name))) {
-			g_free(dentry->name);
-			dentry->name=g_strdup("???");
+		if (string_empty (dentry->name)) {
+			g_free (dentry->name);
+			dentry->name = g_strdup ("???");
 		}
 		launcher = load_launcher_applet_full (NULL, dentry, panel, pos, exactpos);
 		if (launcher != NULL)
-			launcher_save (launcher);
+			launcher_hoard (launcher);
 
 		panel_config_sync_schedule ();
 	} else if(button == 2/*help*/) {
@@ -703,7 +730,7 @@ really_add_launcher(GtkWidget *dialog, int button, gpointer data)
 		return;
 	}
 
-	gtk_widget_destroy(dialog);
+	gtk_widget_destroy (dialog);
 }
 
 void
@@ -863,9 +890,10 @@ convert_dentry_to_gnome (GnomeDesktopEntry *dentry)
 		if (strcmp (dentry->exec[i], "\"%c\"") == 0 ||
 		    strcmp (dentry->exec[i], "%c") == 0) {
 			g_free (dentry->exec[i]);
-			dentry->exec[i] = g_strdup_printf ("'%s'", dentry->name);
+			dentry->exec[i] = g_strdup_printf ("'%s'",
+							   sure_string (dentry->name));
 		} else if (dentry->exec[i][0] == '%' &&
-		    strlen(dentry->exec[i]) == 2) {
+			   strlen(dentry->exec[i]) == 2) {
 			g_free (dentry->exec[i]);
 			dentry->exec[i] = g_strdup ("");
 		}
@@ -883,7 +911,7 @@ static char *
 launcher_get_unique_file (void)
 {
 	int rnd, word;
-#define NUM_OF_WORDS 6
+#define NUM_OF_WORDS 12
 	char *words[] = {
 		"foo",
 		"bar",
@@ -891,6 +919,12 @@ launcher_get_unique_file (void)
 		"gegl",
 		"frobate",
 		"hadjaha",
+		"greasy",
+		"hammer",
+		"eek",
+		"larry",
+		"curly",
+		"moe",
 		NULL};
 	char *fname, *full;
 
@@ -921,6 +955,7 @@ launcher_file_name (const char *base)
 #warning FIXME: per session config must be done for launchers
 #endif
 #else
+	g_return_val_if_fail (base != NULL, NULL);
 	return g_strdup_printf ("%s/.gnome/panel.d/default/launchers/%s",
 				g_get_home_dir (),
 				base);
@@ -935,12 +970,12 @@ launcher_save (Launcher *launcher)
 	g_return_if_fail (launcher->dentry != NULL);
 
 	if (launcher->dentry->is_kde)
-		convert_dentry_to_gnome(launcher->dentry);
+		convert_dentry_to_gnome (launcher->dentry);
 
 	if (launcher->dentry->location == NULL)
 		launcher->dentry->location = launcher_get_unique_file ();
 
-	gnome_desktop_entry_save(launcher->dentry);
+	gnome_desktop_entry_save (launcher->dentry);
 }
 
 void
